import requests
import re

class Towise:
    def __init__(self,app_id,app_key):
        self.headers = {
            "appid":app_id,
            "appkey":app_key,
            'accept': 'application/json'
        }
        self._baseURL= "https://api.towise.io"
        self._detect = {
                "face":"/detect/face",
                "body":"/detect/person",
                "emotion":"/detect/emotion"
        }
        self._recognize = {
                "face":"/recognize/face"
        }
        self._persons = "/persons/"
        self._faces = "/faces/"

    def checkImage(self,image):
        res = {}
        if(re.match("(data:image)",image)):
            res['image_base64'] = image
        else:
            res['image_url'] = image
        
        return res
    
    def faceDetect(self,image):
        data = self.checkImage(image)
        res = requests.post(url = self._baseURL + self._detect['face'], headers=self.headers, data = data)
        return res.json()

    def bodyDetect(self,image):
        data = self.checkImage(image)
        res = requests.post(url = self._baseURL + self._detect['body'], headers=self.headers, data = data)
        return res.json()
    
    def emotionDetect(self,image):
        data = self.checkImage(image)
        res = requests.post(url = self._baseURL + self._detect['emotion'], headers=self.headers, data = data)
        return res.json()

    def faceComparing(self,image):
        data = self.checkImage(image)
        res = requests.post(url = self._baseURL + self._recognize['face'], headers=self.headers, data = data)
        return res.getjson()
    
    def getAllPerson(self):
        res = requests.get(url = self._baseURL + self._persons, headers=self.headers)
        return res.json()
    
    def getPerson(self,person_id):
        params = {"person_id":person_id}
        res = requests.get(url = self._baseURL + self._persons, headers=self.headers, params = params)
        return res.json()
    
    def addPerson(self,name):
        data = {"name":name}
        res = requests.post(url = self._baseURL + self._persons, headers=self.headers, data = data)
        return res.json()

    def removePerson(self,person_id):
        data = {"person_id":person_id}
        res = requests.delete(url = self._baseURL + self._persons, headers=self.headers, data = data)
        return res.json()
    
    def getAllFace(self,person_id):
        params = {"person_id":person_id}
        res = requests.get(url = self._baseURL + self._faces, headers=self.headers, params = params)
        return res.json()

    def getFace(self,face_id):
        params = {"face_id":face_id}
        res = requests.get(url = self._baseURL + self._faces, headers=self.headers, params = params)
        return res.json()
    
    
    def addFace(self,image,person_id,save):
        data = self.checkImage(image)
        data["person_id"] = person_id
        data["save_image"] = save
        res = requests.post(url = self._baseURL + self._faces, headers=self.headers, data = data)
        return res.json()
    
    def removeFace(self, face_id):
        data = {"face_id":face_id}
        res = requests.delete(url = self._baseURL + self._faces, headers=self.headers, data = data)
        return res.json()


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()
setuptools.setup(
  name = 'towise',         # How you named your package folder (MyLib)
  packages = setuptools.find_packages(),   # Chose the same as "name"
  version = '0.1.7',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Towise assists you to detect human faces and bodies with using the latest and reliable technology.',   # Give a short description about your library
  author='Harun KELEŞOĞLU',
  author_email='harunkelesoglu_@hotmail.com',
  url = 'https://github.com/argedor/TowisePythonAPI.git',   # Provide either the link to your github or to your website
  download_url = "https://github.com/argedor/TowisePythonAPI/archive/1.7.tar.gz",    # I explain this later on
  keywords = ['towise', 'face detection', 'body detection','emotion detection','face comparing'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
           'requests'
      ],
  classifiers=[
        "Programming Language :: Python :: 3.6",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
  ],
)